summaryrefslogtreecommitdiffstats
path: root/src/configdialog.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:14:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:14:31 -0600
commit145d30f0b8cbacc3599379e8717299734f3bb534 (patch)
tree3713677dce079619063612b12788282fd32e53af /src/configdialog.h
parent5b6d393e0a2c88cce8f433607c091ae883ef54f9 (diff)
downloadtellico-145d30f0b8cbacc3599379e8717299734f3bb534.tar.gz
tellico-145d30f0b8cbacc3599379e8717299734f3bb534.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'src/configdialog.h')
-rw-r--r--src/configdialog.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/configdialog.h b/src/configdialog.h
index 4204c11..d547b65 100644
--- a/src/configdialog.h
+++ b/src/configdialog.h
@@ -19,7 +19,7 @@
#include <kdialogbase.h>
#include <klistview.h>
-class KConfig;
+class TDEConfig;
class KLineEdit;
class KIntSpinBox;
class KPushButton;
@@ -63,14 +63,14 @@ public:
* Reads the current configuration. Only the options which are not saved somewhere
* else are read at this point.
*
* @param config A pointer to the KConfig object
*/
void readConfiguration();
/**
* Saves the configuration. @ref KConfigBase::sync is called. This method is called
* from the main Tellico object.
*
* @param config A pointer to the KConfig object
*/
void saveConfiguration();
@@ -63,14 +63,14 @@ public:
* else are read at this point.
*
- * @param config A pointer to the KConfig object
+ * @param config A pointer to the TDEConfig object
*/
void readConfiguration();
@@ -63,14 +63,14 @@ public:
void readConfiguration();
/**
- * Saves the configuration. @ref KConfigBase::sync is called. This method is called
+ * Saves the configuration. @ref TDEConfigBase::sync is called. This method is called
* from the main Tellico object.
*
@@ -63,14 +63,14 @@ public:
* from the main Tellico object.
*
- * @param config A pointer to the KConfig object
+ * @param config A pointer to the TDEConfig object
*/
void saveConfiguration();